@@ -16,10 +16,11 @@
 #
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
-
 """ This module contains the base class for handlers as used by the
 Dispatcher """
 
+from telegram.utils.deprecate import deprecate
+
 
 class Handler(object):
     """
@@ -28,18 +29,24 @@ class Handler(object):
 
     Args:
         callback (function): A function that takes ``bot, update`` as
-            positional arguments. It will be called when the ``checkUpdate``
+            positional arguments. It will be called when the ``check_update``
             has determined that an update should be processed by this handler.
-        pass_update_queue (optional[bool]): If the callback should be passed
-            the update queue as a keyword argument called ``update_queue``. It
-            can be used to insert updates. Default is ``False``
+        pass_update_queue (optional[bool]): If set to ``True``, a keyword argument called
+            ``update_queue`` will be passed to the callback function. It will be the ``Queue``
+            instance used by the ``Updater`` and ``Dispatcher`` that contains new updates which can
+             be used to insert updates. Default is ``False``.
+        pass_job_queue (optional[bool]): If set to ``True``, a keyword argument called
+            ``job_queue`` will be passed to the callback function. It will be a ``JobQueue``
+            instance created by the ``Updater`` which can be used to schedule new jobs.
+            Default is ``False``.
     """
 
-    def __init__(self, callback, pass_update_queue=False):
+    def __init__(self, callback, pass_update_queue=False, pass_job_queue=False):
         self.callback = callback
         self.pass_update_queue = pass_update_queue
+        self.pass_job_queue = pass_job_queue
 
-    def checkUpdate(self, update):
+    def check_update(self, update):
         """
         This method is called to determine if an update should be handled by
         this handler instance. It should always be overridden.
@@ -52,20 +59,22 @@ class Handler(object):
         """
         raise NotImplementedError
 
-    def handleUpdate(self, update, dispatcher):
+    def handle_update(self, update, dispatcher):
         """
         This method is called if it was determined that an update should indeed
         be handled by this instance. It should also be overridden, but in most
-        cases call self.callback(dispatcher.bot, update), possibly along with
-        optional arguments.
+        cases call ``self.callback(dispatcher.bot, update)``, possibly along with
+        optional arguments. To work with the ``ConversationHandler``, this method should return the
+        value returned from ``self.callback``
 
         Args:
             update (object): The update to be handled
+            dispatcher (Dispatcher): The dispatcher to collect optional args
 
         """
         raise NotImplementedError
 
-    def collectOptionalArgs(self, dispatcher):
+    def collect_optional_args(self, dispatcher):
         """
         Prepares the optional arguments that are the same for all types of
         handlers
@@ -76,5 +85,14 @@ class Handler(object):
         optional_args = dict()
         if self.pass_update_queue:
             optional_args['update_queue'] = dispatcher.update_queue
+        if self.pass_job_queue:
+            optional_args['job_queue'] = dispatcher.job_queue
 
         return optional_args
+
+    # old non-PEP8 Handler methods
+    m = "telegram.Handler."
+    checkUpdate = deprecate(check_update, m + "checkUpdate", m + "check_update")
+    handleUpdate = deprecate(handle_update, m + "handleUpdate", m + "handle_update")
+    collectOptionalArgs = deprecate(collect_optional_args, m + "collectOptionalArgs",
+                                    m + "collect_optional_args")
